###########################################################################
#
# win32 makefile -- src/w32server
# A component of the Greenstone digital library software
# from the New Zealand Digital Library Project at the
# University of Waikato, New Zealand.
#
# Copyright (C) 1999  The New Zealand Digital Library Project
#
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
#
###########################################################################

GSDLHOME = ..\..
GSDL_VC4 = 0
STLPATH = "$(GSDLHOME)\packages\windows\stlport\stlport"
ENABLE_ACCENTFOLD = 1

AR = lib
CC = cl
RSC = rc

!IF $(GSDL_VC4)
CPPFLAGS = -GX
!ELSE
CPPFLAGS = -EHsc
!ENDIF

LDFLAGS =
DEFS = -DHAVE_CONFIG_H -D_LITTLE_ENDIAN -DPARADOCNUM -D__WIN32__ \
       -DSHORT_SUFFIX -D_CRT_SECURE_NO_DEPRECATE
INCLUDES = -I"$(GSDLHOME)\src\w32server" -I"$(GSDLHOME)\src\recpt" -I"$(GSDLHOME)\lib" \
	   -I"$(GSDLHOME)\src\colservr" -I"$(GSDLHOME)\indexers\mg" \
	   -I"$(GSDLHOME)\indexers\mg\lib" -I"$(GSDLHOME)\indexers\mg\src\text" \
	   -I"$(GSDLHOME)\indexers\mgpp\lib" -I"$(GSDLHOME)\indexers\mgpp\text" -I"$(GSDLHOME)"
!IF $(GSDL_VC4)
DEFS = $(DEFS) -DGSDL_NAMESPACE_BROKEN -DGSDL_USE_IOS_H -D__STL_NO_NEW_IOSTREAMS
INCLUDES = $(INCLUDES) -I$(STLPATH)
!ENDIF

!IF $(ENABLE_ACCENTFOLD)
AFLIBS = "$(GSDLHOME)\indexers\packages\unac\libunac.lib" "$(GSDLHOME)\indexers\packages\unac\iconv.lib"
DEFS = $(DEFS) -DENABLE_ACCENTFOLD
!ELSE
AFLIBS = 
!ENDIF

LIBS = "$(GSDLHOME)\lib\gsdllib.lib" \
       "$(GSDLHOME)\indexers\mg\src\text\libmgtext.lib" \
       "$(GSDLHOME)\indexers\mg\lib\libmglib.lib" \
       "$(GSDLHOME)\src\colservr\gsdlcolservr.lib" \
       "$(GSDLHOME)\src\recpt\gsdlrecpt.lib" \
       "$(GSDLHOME)\packages\windows\gdbm\gdbm\gdbm.lib" \
       "$(GSDLHOME)\packages\windows\crypt\crypt\crypt.lib" \
       "$(GSDLHOME)\indexers\mgpp\lib\libmgpplib.lib" \
       "$(GSDLHOME)\indexers\mgpp\text\libmgpptext.lib" \
       "$(GSDLHOME)\packages\windows\expat\expat\libexpat.lib" \
	$(AFLIBS)


WINLIBS = kernel32.lib user32.lib gdi32.lib winspool.lib \
          comdlg32.lib advapi32.lib shell32.lib ole32.lib \
          oleaut32.lib uuid.lib odbc32.lib odbccp32.lib 
#wsock32.lib

COMPILE = $(CC) -nologo -c $(CPPFLAGS) $(DEFS) $(INCLUDES)
LINK = $(CC) -nologo $(LDFLAGS) -Fe"$@"

.SUFFIXES:
.SUFFIXES: .c .obj
.c.obj:
	$(COMPILE) $<

.SUFFIXES: .cpp .obj
.cpp.obj:
	$(COMPILE) $< 

HEADERS = cgiwrapper.h conftools.h d_winsock.h fnord.h httpreq.h httpsend.h \
          httpsrv.h locate.h netio.h parse.h settings.h startbrowser.h \
	  wincgiutils.h

SOURCES = cgiwrapper.cpp conftools.cpp d_winsock.cpp fnord.cpp httpreq.cpp httpsend.cpp \
          httpsrv.cpp locate.cpp netio.cpp parse.cpp settings.cpp startbrowser.cpp \
	  wincgiutils.cpp

OBJECTS = cgiwrapper.obj conftools.obj d_winsock.obj fnord.obj httpreq.obj httpsend.obj \
          httpsrv.obj locate.obj netio.obj parse.obj settings.obj startbrowser.obj \
	  wincgiutils.obj server.res

EXEC = server.exe

all: $(EXEC)

clean:
	del *.obj
	del $(EXEC)

install:
	copy $(EXEC) "$(GSDLHOME)"

server.exe: $(OBJECTS) $(LIBS)
	    $(LINK) $(OBJECTS) $(LIBS) $(WINLIBS) 


SOURCE = "$(GSDLHOME)\src\w32server\newgsdl.bmp"
SOURCE = "$(GSDLHOME)\src\w32server\resource.h"
SOURCE = "$(GSDLHOME)\src\w32server\server.ico"
SOURCE = "$(GSDLHOME)\src\w32server\gsdlcol.bmp"
SOURCE = "$(GSDLHOME)\src\w32server\server.rc"
DEP_RSC_SERVE=\
	"$(GSDLHOME)\src\w32server\gsdlcol.bmp"\
	"$(GSDLHOME)\src\w32server\newgsdl.bmp"\
	"$(GSDLHOME)\src\w32server\server.ico"

server.res : $(SOURCE) $(DEP_RSC_SERVE) "$(GSDLHOME)\src\w32server"
   $(RSC) /l 0x409 /fo"$(GSDLHOME)\src\w32server\server.res" /i "$(GSDLHOME)\src\w32server" \
 /d "NDEBUG" $(SOURCE)


"$(GSDLHOME)\src\w32server\server.res" : $(SOURCE) $(DEP_RSC_SERVE) "$(GSDLHOME)\src\w32server"
   $(RSC) /l 0x409 /fo"$(GSDLHOME)\src\w32server\server.res" /i "$(GSDLHOME)\src\w32server" \
 /d "NDEBUG" $(SOURCE)

